@@ -79,6 +79,8 @@ def run( options ):
                                                         depth2 )
     twoconditionscore.build()
     twoconditionscore.finalize()
+    twoconditionscore.compute_all_pvalues()
+    twoconditionscore.compute_track_qvalues()
     #(cat1,cat2,cat3,cat4) = twoconditionscore.call_peaks(min_length=options.minlen, cutoff=options.cutoff)
     (cat1,cat2,cat3) = twoconditionscore.call_peaks(min_length=options.minlen, cutoff=options.cutoff)
 
